@@ -169,13 +169,20 @@ class Twilio2FAMixin(object):
             del self.request.session[key_]
 
     def get_phone_number(self):
-        return get_setting(
+        phone_number = get_setting(
             "PHONE_NUMBER_CB",
             callback_kwargs={
                 "user": self.request.user
             }
         )
 
+        try:
+            phone_number = parse_phone_number(phone_number)
+        except ValidationError:
+            phone_number = None
+
+        return phone_number
+
 
 class Twilio2FAVerificationMixin(Twilio2FAMixin):
     """
@@ -187,11 +194,6 @@ class Twilio2FAVerificationMixin(Twilio2FAMixin):
 
         self.phone_number = self.get_phone_number()
 
-        try:
-            self.phone_number = parse_phone_number(self.phone_number)
-        except ValidationError:
-            self.phone_number = None
-
         self.timeout_value = get_setting(
             "TIMEOUT_CB",
             callback_kwargs={
@@ -435,13 +437,6 @@ class Twilio2FAStartView(Twilio2FAVerificationMixin, TemplateView):
                 can_retry=False
             )
 
-        if not self.phone_number:
-            messages.warning(
-                request,
-                _("You must add a phone number to your account before proceeding.")
-            )
-            return self.get_redirect("register")
-
         action = request.GET.get("action")
 
         if not self.phone_number:
